RequestParameters

Enum RequestParameters 

pub enum RequestParameters<ValueT = Value> {
    ByPosition(Vec<ValueT>),
    ByName(BTreeMap<String, ValueT>),
}
If present, parameters for the rpc call MUST be provided as a Structured value. Either by-position through an Array or by-name through an Object.

Variants



ByPosition(Vec<ValueT>)

params MUST be an Array, containing the values in the Server expected order.



ByName(BTreeMap<String, ValueT>)

params MUST be an Object, with member names that match the Server expected parameter names. The absence of expected names MAY result in an error being generated. The names MUST match exactly, including case, to the method’s expected parameters.

Implementations

Source

impl<T> RequestParameters<T>

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool