Request

Struct Request 

pub struct Request<MethodT = String, IdT = Id, RequestParametersT = RequestParameters<Value>> {
    pub method: MethodT,
    pub params: Option<RequestParametersT>,
    pub id: Option<IdT>,
}
A JSON-RPC 2.0 request object.

Note that the "jsonrpc": "2.0" member is transparently checked during deserialization, and added during serialization.

Fields

method: MethodT

A String containing the name of the method to be invoked. Method names that begin with the word rpc followed by a period character (U+002E or ASCII 46) are reserved for rpc-internal methods and extensions and MUST NOT be used for anything else.

params: Option<RequestParametersT>

A Structured value that holds the parameter values to be used during the invocation of the method. This member MAY be omitted.

id: Option<IdT>

An identifier established by the Client that MUST contain a String, Number, or NULL value if included. If it is not included it is assumed to be a notification. The value SHOULD normally not be Null and Numbers SHOULD NOT contain fractional parts

Implementations

Source

impl<T> Request<T>

pub const fn is_notification(&self) -> bool